@@ -76,19 +76,20 @@ as_html <- function(x,
 
   stopifnot(is(x, "VTableTree"))
 
-  mat <- matrix_form(x)
+  mat <- matrix_form(x, indent_rownames = TRUE)
 
   nlh <- mf_nlheader(mat)
   nc <- ncol(x) + 1
+  nr <- length(mf_lgrouping(mat))
 
   # Structure is a list of lists with rows (one for each line grouping) and cols as dimensions
-  cells <- matrix(rep(list(list()), (nlh + nrow(x)) * (nc)), ncol = nc)
+  cells <- matrix(rep(list(list()), (nr * nc)), ncol = nc)
 
-  for (i in seq_len(nrow(mat$strings))) {
-    for (j in seq_len(ncol(mat$strings))) {
-      curstrs <- mat$strings[i, j]
-      curspn <- mat$spans[i, j]
-      algn <- mat$aligns[i, j]
+  for (i in seq_len(nr)) {
+    for (j in seq_len(nc)) {
+      curstrs <- mf_strings(mat)[i, j]
+      curspn <- mf_spans(mat)[i, j]
+      algn <- mf_aligns(mat)[i, j]
 
       inhdr <- i <= nlh
       tagfun <- if (inhdr) tags$th else tags$td
@@ -110,18 +111,32 @@ as_html <- function(x,
     )
   }
 
-  # row labels style
-  for (i in seq_len(nrow(x))) {
-    indent <- mat$row_info$indent[i]
-    if (indent > 0) { # indentation
-      cells[i + nlh, 1][[1]] <- htmltools::tagAppendAttributes(cells[i + nlh, 1][[1]],
+  # Create a map between line numbers and line groupings, adjusting abs_rownumber with nlh
+  map <- data.frame(lines = seq_len(nr), abs_rownumber = mat$line_grouping)
+  row_info_df <- data.frame(indent = mat$row_info$indent, abs_rownumber = mat$row_info$abs_rownumber + nlh)
+  map <- merge(map, row_info_df, by = "abs_rownumber")
+
+  # add indent values for headerlines
+  map <- rbind(data.frame(abs_rownumber = 1:nlh, indent = 0, lines = 0), map)
+
+
+  # Row labels style
+  for (i in seq_len(nr)) {
+    indent <- ifelse(any(map$lines == i), map$indent[map$lines == i][1], -1)
+
+    # Apply indentation
+    if (indent > 0) {
+      cells[i, 1][[1]] <- htmltools::tagAppendAttributes(
+        cells[i, 1][[1]],
         style = paste0("padding-left: ", indent * 3, "ch;")
       )
     }
-    if ("row_names" %in% bold) { # font weight
-      cells[i + nlh, 1][[1]] <- htmltools::tagAppendAttributes(
-        cells[i + nlh, 1][[1]],
-        style = paste0("font-weight: bold;")
+
+    # Apply bold font weight if "row_names" is in 'bold'
+    if ("row_names" %in% bold) {
+      cells[i, 1][[1]] <- htmltools::tagAppendAttributes(
+        cells[i, 1][[1]],
+        style = "font-weight: bold;"
       )
     }
   }
